Module authorization_server

Module authorization_server 

Generated server implementations.

Structs

AuthorizationServer
A generic interface for performing authorization check on incoming requests to a networked service.

Traits

Authorization
Generated trait containing gRPC methods that should be implemented for use with AuthorizationServer.