Generated server implementations.
Structs
- Authorization
Server - A generic interface for performing authorization check on incoming requests to a networked service.
Traits
- Authorization
- Generated trait containing gRPC methods that should be implemented for use with AuthorizationServer.